using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Diagnostics;
using System.Runtime.InteropServices;
using SlimDX.DirectInput;
using PolledDevices;

namespace PolledDevices.TestKeyboard
{
	public partial class MainForm : System.Windows.Forms.Form
	{
		private PolledDevices.PolledKeyboard _keyboard;

		public MainForm()
		{
			InitializeComponent();

			_keyboard = new PolledKeyboard(this);
			
			_keyboard.DeviceAcquiredEvent += new EventHandler(OnKeyboardAcquired);
			_keyboard.DeviceReleasedEvent += new EventHandler(OnKeyboardReleased);
			_keyboard.DeviceLostEvent += new EventHandler(OnKeyboardLost);

			_keyboard.KeyboardPolledEvent += new PolledKeyboardEventHandler(OnKeyboardPolled);
			_keyboard.KeyboardDownEvent += new PolledKeyboardEventHandler(OnKeyboardDown);
			_keyboard.KeyboardUpEvent += new PolledKeyboardEventHandler(OnKeyboardUp);
		}

        [DllImport("user32.dll")]
        public static extern IntPtr SetFocus(IntPtr hWnd);

        private void MainForm_Load(object sender, EventArgs e)
        {
            _keyboard.Acquire();
            Process notepad = Process.Start("notepad.exe");
            SetFocus(notepad.MainWindowHandle);
        }

        private void MainForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            _keyboard.Release();
        }

        private void MainForm_FormClosed(object sender, FormClosedEventArgs e)
        {
            _keyboard.Release(); // ensure
        }

		private void OnKeyboardAcquired(object sender, EventArgs e)
		{
			Console.WriteLine("Acquired");
		}

		private void OnKeyboardReleased(object sender, EventArgs e)
		{
			Console.WriteLine("Released");
		}

		private void OnKeyboardLost(object sender, EventArgs e)
		{
			Console.WriteLine("Lost");
		}

		private void OnKeyboardPolled(object sender, PolledKeyboardEventArgs e)
		{
			// nothing
		}

		private void OnKeyboardDown(object sender, PolledKeyboardEventArgs e)
		{
			MyText.Text += e.Key + " ";
			MyText.SelectionStart = MyText.Text.Length;
			MyText.SelectionLength = 0;
		}

		private void OnKeyboardUp(object sender, PolledKeyboardEventArgs e)
		{
			// nothing
		}

	}
}
