using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using PolledDevices;

namespace PolledDevices.TestMouse
{
	public partial class MainForm : System.Windows.Forms.Form
	{
		private PolledDevices.PolledMouse _mouse;

		public MainForm()
		{
			InitializeComponent();
			
			_mouse = new PolledMouse(this);
			
			_mouse.DeviceAcquiredEvent += new EventHandler(OnMouseAcquired);
			_mouse.DeviceReleasedEvent += new EventHandler(OnMouseReleased);
			_mouse.DeviceLostEvent += new EventHandler(OnMouseLost);
			
			_mouse.MousePolledEvent += new PolledMouseEventHandler(OnMousePolled);
			_mouse.MouseMoveEvent += new PolledMouseEventHandler(OnMouseMove);
			_mouse.MouseDownEvent += new PolledMouseEventHandler(OnMouseDown);
			_mouse.MouseUpEvent += new PolledMouseEventHandler(OnMouseUp);
		}

        private void MainForm_Load(object sender, EventArgs e)
        {
            _mouse.Acquire();
        }

        private void MainForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            _mouse.Release();
        }

        private void MainForm_FormClosed(object sender, FormClosedEventArgs e)
        {
            _mouse.Release(); // ensure
        }

		private void OnMouseAcquired(object sender, EventArgs e)
		{
			Console.WriteLine("Acquired");
		}

		private void OnMouseReleased(object sender, EventArgs e)
		{
			Console.WriteLine("Released");
		}

		private void OnMouseLost(object sender, EventArgs e)
		{
			Console.WriteLine("Lost");
		}

		private void OnMousePolled(object sender, PolledMouseEventArgs e)
		{
			// nothing
		}

		private void OnMouseMove(object sender, PolledMouseEventArgs e)
		{
            if (!Client.IsDisposed)
			    Client.Text = String.Format("({0}, {1})", e.ClientPos.X, e.ClientPos.Y);
            if (!Screen.IsDisposed)
			    Screen.Text = String.Format("({0}, {1})", e.ScreenPos.X, e.ScreenPos.Y);
		}

		private void OnMouseDown(object sender, PolledMouseEventArgs e)
		{
            if (!ButtonDown.IsDisposed)
			    ButtonDown.Text = String.Format("{0} at ({1}, {2})", e.Button, e.ScreenPos.X, e.ScreenPos.Y);
		}

		private void OnMouseUp(object sender, PolledMouseEventArgs e)
		{
            if (!ButtonUp.IsDisposed)
			    ButtonUp.Text = String.Format("{0} at ({1}, {2})", e.Button, e.ScreenPos.X, e.ScreenPos.Y);
		}

        
	}
}
